@@ -513,8 +513,8 @@ class NDScopePlotChannel(QtCore.QObject):
         color = self.get_QColor()
         pen = pg.mkPen(color, width=self.params['width'])
         mmc = copy.copy(color)
-        mmc.setAlpha(100)
-        mmpen = pg.mkPen(mmc, style=QtCore.Qt.DashLine)
+        mmc.setAlpha(const.TREND_MINMAX_ALPHA)
+        mmpen = pg.mkPen(mmc, width=self.params['width'], style=QtCore.Qt.DashLine)
         self.curves['y'].setPen(pen)
         self.curves['min'].setPen(mmpen)
         self.curves['max'].setPen(mmpen)
