@@ -14,6 +14,7 @@ from qtpy.QtWidgets import QStyle, QFileDialog, QFontDialog
 from qtpy.QtWidgets import QApplication
 from qtpy.QtGui import QFont
 import pyqtgraph as pg
+from pyqtgraph import exporters
 
 # NOTE: must be imported after pyqt or else config is reset
 import logging
@@ -30,7 +31,6 @@ from . import export
 from . import dialog
 from . import channel_select
 
-
 logger = logging.getLogger('SCOPE')
 
 ##################################################
@@ -256,7 +256,7 @@ class NDScope(*load_ui('scope.ui')):
         self.exportPath.returnPressed.connect(self._export_save_handler)
         self.exportSaveButton.clicked.connect(self._export_save_handler)
         self.exportShowButton.clicked.connect(self._export_show_handler)
-        self.exportButton2.clicked.connect(self.export)
+        self.exportButton2.clicked.connect(self.snapshot)
 
         ##########
         # controls
@@ -291,7 +291,7 @@ class NDScope(*load_ui('scope.ui')):
         self.exportButton.setIcon(self.style().standardIcon(QStyle.SP_DialogSaveButton))
         self.exportSaveButton.setIcon(self.style().standardIcon(QStyle.SP_DialogSaveButton))
         self.exportShowButton.setIcon(self.style().standardIcon(QStyle.SP_FileDialogContentsView))
-        self.exportButton2.setIcon(self.style().standardIcon(QStyle.SP_DialogSaveButton))
+        # self.exportButton2.setIcon(self.style().standardIcon(QStyle.SP_DialogSaveButton))
 
         ##########
         # initial config
@@ -1697,3 +1697,20 @@ class NDScope(*load_ui('scope.ui')):
             except FileNotFoundError:
                 self.status_error("xdg-open binary not found.  Please install 'xdg-utils' package.")
             # FIXME: catch open errors even though process backgrounded?
+
+    def snapshot(self):
+        """Take snapshot of scene (PNG) and copy to clipboard
+
+        """
+        try:
+            scene = self.graphView.scene()
+            if os.getenv('XDG_SESSION_TYPE') == 'wayland':
+                image = export.export_scene_png(scene)
+                subprocess.run(['wl-copy'], input=image)
+            else:
+                exporters.ImageExporter(scene).export(copy=True)
+        except Exception as e:
+            logger.info(traceback.format_exc())
+            self.status_error(str(e))
+            return
+        self.status_message(f"Copied scene snapshot to clipboard (as png)", timeout=10)
